@@ -92,7 +92,6 @@ function eor ()
     exit();
 }
 
-
 // Langage settings
 if ($App->getParam('LANG')) {
     $LANG = $App->getParam('LANG');
@@ -116,12 +115,6 @@ else {
     }
 }
 
-if (preg_match('/admin.php/',$_SERVER['SCRIPT_FILENAME'])) {
-    $App->setSkin($App->getConfig('SKINDIR','admin'),$header_template);
-}
-else {                          // user templates
-    $App->setSkin($App->getConfig('SKINDIR','user'),$header_template);
-}
 
 // fetch user variable from session
 $USER  = $App->getSession('USER');
@@ -247,10 +240,6 @@ $App->assign('SID',session_id());
 $App->assign('SN',session_name());
 $App->assign('VIEW',$App->view);
 
-if ($App->getParam('SKIN')) {
-    $App->setSkin($App->getParam('SKIN'));
-}
-
 $App->log("TPL[$ACCESS_LEVEL] $App->view",2,'SPAF2');
 $App->template = $App->view;
 // header and footer relative to template_root
