@@ -295,13 +295,12 @@ class Application extends ApplicationConfig
         $this->module   = $MODULE;
         $this->_request = & $_REQUEST;
         $this->_session = & $_SESSION;
-        $this->DEBUG = $this->getConfig('DEBUG');
+        $this->DEBUG    = $this->getConfig('DEBUG');
 
-        $this->tpl_root = getcwd().'/'.$this->getConfig('TEMPLATE_ROOT','../')
-                          .'/templates';
         $this->TPL = new Smarty;
         $this->TPL->error_reporting = false;
         $this->TPL->compile_check   = true;
+        $this->setSkin($this->getConfig('SKIN_DIR'));
 
         if (isset($this->config['DBTYPE'])) {
             $this->DB = new DBAccess($this->config['DBTYPE'],$this->config['DBUSER'],
@@ -497,7 +496,7 @@ class Application extends ApplicationConfig
     {
         // initialize cache
         $templates_cache_base = $this->getConfig('TEMPLATE_CACHE','/var/cache/benno-web/templates_c');
-        $templates_cache_skin = $templates_cache_base.'/'.$this->skin;
+        $templates_cache_skin = $templates_cache_base.'/'.basename($this->tpl_root);
         if (!is_dir($templates_cache_skin)) {
             mkdir($templates_cache_skin);
         }
@@ -508,8 +507,8 @@ class Application extends ApplicationConfig
             $this->log('warning: cannot write to templates cache: '.$templates_cache_skin,0,'spaf2/app');
             $this->TPL->compile_dir = '/tmp';
         }
-        $this->TPL->config_dir   = $this->configdir;
-        $this->TPL->cache_dir    = $this->tpl_root . '/cache';
+        $this->TPL->config_dir  = $this->configdir;
+        $this->TPL->cache_dir   = Smarty::CACHING_OFF;
 
         if ($debug = $this->getparam('DEBUG')) {
             $this->setSession('DEBUG',$debug);
@@ -542,6 +541,7 @@ class Application extends ApplicationConfig
      */
     function log ($message,$threshold=0,$module='')
     {
+        global $USER;
         $view = '-';
         if ($this->view != '') {
             $view = $this->view;
@@ -550,6 +550,17 @@ class Application extends ApplicationConfig
             $view = $module;
         }
 
+        $debug_user = $this->getConfig('DEBUG_USER');
+        if ($debug_user) {
+            list($debug_user,$debug_level) = explode(':',$debug_user);
+            if ($debug_user == $USER->id) {
+                if ($debug_level >= $threshold) {
+                    error_log("$debug_user:[$threshold:$view] $message");
+                }
+                return;
+            }
+        }
+
         $debug_vals   = preg_split('/,(\s+)?/',$this->DEBUG);
         $debug_global = array_shift($debug_vals) or 0;
         foreach ($debug_vals as $debug_entry) {
@@ -559,6 +570,7 @@ class Application extends ApplicationConfig
                 return;
             }
         }
+
         if ($debug_global >= $threshold) {
             error_log("[$threshold:$view] $message");
         }
@@ -947,17 +959,29 @@ class Application extends ApplicationConfig
      * @access public
      * @param $skin string
      */
-    function setSkin($skindir='',$header_template='header.tpl')
+    function setSkin($skindir='')
     {
-        if (!$skindir) {
-            $skindir = 'default';
+        $subpage = 'user';
+        if (preg_match('/admin.php/',$_SERVER['SCRIPT_FILENAME'])) {
+                $subpage = 'admin';    
         }
-        $this->skin = $skindir;
-        $tpl_dir  = $this->tpl_root.'/'.$skindir;
-        if (!is_file($tpl_dir.'/'.$header_template)) {
-            $this->log("Warning: Skin $tpl_dir not initialized.",2,'spaf2/app');
-            $tpl_dir = $this->tpl_root.'/default';
+
+        $tpl_root = getcwd().'/'.$this->getConfig('TEMPLATE_ROOT','../').'/templates';
+        $tpl_root = preg_replace('/\/\//','/',$tpl_root);
+        $tpl_dir  = $tpl_root.'/'.$subpage;
+
+        if ($skindir) {
+            $skin_tpl = $skindir.'/'.$subpage;
+            if (is_dir($skin_tpl) && is_readable($skin_tpl)) {
+                $tpl_root = $skindir;
+                $tpl_dir  = $skindir.'/'.$subpage;
+            }
+            else {
+                $this->log("WARNING skindir $skin_tpl does not exist or is not readable.",2,'spaf2/app');
+            }
         }
+
+        $this->tpl_root = $tpl_root;
         $this->TPL->setTemplateDir($tpl_dir);
     }
 
