@@ -47,16 +47,18 @@ try {
     $rawMail = preg_replace('/^Message-Id:/im','X-Benno-Resent-Message-Id:',$rawMail);
 
     $msgIdHeader = 'Message-ID: <'.uniqid('',true).'@'.php_uname('n').'>';
+    $msgIdHeader = 'Message-ID: <'.uniqid('',true).'@'.gethostbyaddr(gethostbyname(gethostname())).'>';
 
     $send_to = escapeshellarg($mailTo);
     $sendmail = "$sendmail_cmd -i -f $mail_from $send_to";
+    $env['BENNOWEB_CONFIG'] = $configfile;
 
     $fd = array(
         0 => array('pipe', 'r'),
         1 => array('pipe', 'w'),
         2 => array('pipe', 'w')
     );
-    $process = proc_open($sendmail, $fd, $pipes);
+    $process = proc_open($sendmail, $fd, $pipes, null, $env);
     if (is_resource($process)) {
         // write "<username>$auth_sep<password>"
         fwrite($pipes[0],$msgIdHeader."\r\n".$rawMail);
@@ -69,6 +71,7 @@ try {
         $errstring = stream_get_contents($pipes[2]);
         fclose($pipes[2]);
         $closevalue = proc_close($process);
+
         if ($errstring) {
             throw new Exception("Error send mail: \"$errstring\" ($closevalue)");
         }
