@@ -31,6 +31,9 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 require_once './model/User.php';
+require_once 'ctrl/CsrfToken.php';
+
+CsrfToken::generate();
 
 $id = $App->getParam('id');
 if ($id) {
