@@ -44,7 +44,7 @@ if ($lastArchive != 'SYSDATA') {    // -> FS#929
 $exitview = $App->getSession('exitview');
 
 try {
-    $Backend->destroy_bennorest_session();
+    $Backend->destroy_bennorest_session($archive);
 }
 catch (Exception $e) {
     $App->log('[logoff] '.$e->getMessage());
