@@ -30,7 +30,7 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/lib/benno-web/benno_dbauth');
+$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/sbin/benno_auth.d');
 
 // Authentication
 if (! $passwd) {
