@@ -32,7 +32,7 @@
  */
 
 
-$extForm = $App->getParam('ext');
+$extForm = $App->getParam('ext',true);
 $queryId = sha1(serialize($extForm));
 
 try {
