@@ -57,6 +57,7 @@ catch (Exception $e) {
     $App->setMsg($e->getMessage());
 }
 
-$App->view = 'showList';
-
+$redirect_params['queryData'] = $Query->getUrlParameter();
+$redirect_params['startNum']  = $startNum;
+$App->redirect('searchQuery',$redirect_params);
 ?>
