@@ -32,6 +32,9 @@
  */
 
 require_once 'model/AppState.php';
+require_once 'ctrl/CsrfToken.php';
+
+CsrfToken::generate();
 
 foreach ($USER->getArchives() as $archive) {
     $users = User::FetchList($archive);
