@@ -30,8 +30,10 @@
  * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
  * Suite 330, Boston, MA  02111-1307  USA
  */
-
-$configfile = "/etc/benno-web/benno.conf";
+$configfile = getenv('BENNOWEB_CONFIG');
+if (! $configfile) {
+    $configfile = "/etc/benno-web/benno.conf";
+}
 $header_template = 'header.tpl';
 $footer_template = 'footer.tpl';
 $default_action  = 'default';
