@@ -128,9 +128,38 @@ class AppState extends Persistence
      */
     function saveValue($param,$value)
     {
+        global $App;
+
         $this->id = $param;
         $this->value = $value;
-        parent::save();
+
+        $DB = $App->DB;
+        $DB->startTransaction();
+        try {
+            $sql = 'DELETE FROM appstate WHERE id = ? AND userid = ?';
+            $sth = $DB->db->prepare($sql);
+            $sth->bindValue(1,$this->id);
+            $sth->bindValue(2,$this->userid);
+            $res = $sth->execute();
+        }
+        catch(PDOException $e){ 
+            $App->log('WARNING cannot delete row: '.$e->getMessage(),2);
+        }
+
+        try {
+            $sql = "INSERT INTO appstate (id,userid,value) VALUES (?,?,?)";
+            $sth = $DB->db->prepare($sql);
+            $sth->bindValue(1,$this->id);
+            $sth->bindValue(2,$this->userid);
+            $sth->bindValue(3,$this->value);
+
+            $res = $sth->execute();
+        }
+        catch(PDOException $e){ 
+            $App->log('WARNING cannot insert row: '.$e->getMessage(),2);
+        }
+        $DB->endTransaction();
+
     }
 
 }
