@@ -161,7 +161,7 @@ class License
     {
         global $App;
         preg_match('/^(ERR_\S+):(.+)$/',$msgstring,$matches);
-        if ($matches[1]) {
+        if (array_key_exists(1,$matches)) {
             $errmsg  = $App->getMsg($matches[1]);
             $ret = $errmsg.': '.$matches[2];
         }
