@@ -419,7 +419,6 @@ class Query
         if ($participant == '') { return ''; }
 
         global $App;
-        //$or    = ' OR ';  // necessary??
 
         $sender_query = '';
         $sender_q = $participant.'*';
@@ -429,7 +428,7 @@ class Query
         $sender_string = $this->_format_query($sender_q,'Sender');
         // (!)Sender contains plain email adress without names
         $from_string   = $this->_format_query($sender_q,'From');
-        $sender_query .= '('.$sender_string.$or.$from_string.')';
+        $sender_query .= '('.$sender_string.$from_string.')';
 
         return $sender_query;
     }
@@ -442,7 +441,6 @@ class Query
         if ($participant == '') { return ''; }
 
         global $App;
-        //$or    = ' OR ';  // necessary??
 
         $recipient_query = '';
         $recipient_q = $participant.'*';
@@ -453,9 +451,7 @@ class Query
         $recipient_string = $this->_format_query($recipient_q,'Recipient');
         $to_string        = $this->_format_query($recipient_q,'To');
         $cc_string        = $this->_format_query($recipient_q,'Cc');
-        $recipient_query .= '('.$recipient_string.$or.
-                             $to_string.$or.
-                             $cc_string.')';
+        $recipient_query .= '('.$recipient_string.$to_string.$cc_string.')';
 
         return $recipient_query;
     }
