@@ -36,12 +36,12 @@ $App->assign('LANG',$App->lang);
 
 switch ($App->lang) {
     case 'en':
-        $LOCALE['timeformat'] = '%H:%M';
-        $LOCALE['dateformat'] = '%m/%d/%Y';
+        $LOCALE['timeformat'] = 'H:i';
+        $LOCALE['dateformat'] = 'm/d/Y';
         break;
     default:
-        $LOCALE['timeformat'] = '%H:%M';
-        $LOCALE['dateformat'] = '%d.%m.%Y';
+        $LOCALE['timeformat'] = 'H:i';
+        $LOCALE['dateformat'] = 'd.m.Y';
 }
 $App->assign('LOCALE',$LOCALE);
 
