@@ -77,6 +77,9 @@ $sessionMailId = $App->getSession('sessionMailId');
 $lastRequestTime = $App->getSession('lastRequestTime'); // view/a_sessionRefresh
 $App->setSession('lastRequestTime',time());
 
+// timezone settings
+date_default_timezone_set($App->getSession('clientTimezone'));
+
 $Audit = new Audit();
 
 ?>
