@@ -51,13 +51,12 @@
 // ini_set('include_path',$include_path.':lib');
 
 // ACCESS CONSTANTS
-define('BNO_AUTH',    0b00000010);   //   2 user authenticated
-define('BNO_USER',    0b00000100);   //   4 edit user
-define('BNO_SYSINFO', 0b00001000);   //   8 Show system information
-define('BNO_SYSDATA', 0b00010000);   //  16 SYSDATA container
-define('BNO_ADMIN',   0b00100000);   //  32 admingui (change address, role)
-define('BNO_STATS',   0b01000000);   //  64 statistics
-define('BNO_SITEADM', 0b10000000);   // 128 admingui (change container)
+define('BNO_AUTH',      0b00000010);   //   2 user authenticated
+define('BNO_USER',      0b00000100);   //   4 edit user
+define('BNO_USERADMIN', 0b00001000);   //   8 user admin (change password, userinfo)
+define('BNO_SYSINFO',   0b00010000);   //  16 see sysinfo / SYSDATA container
+define('BNO_ADMIN',     0b00100000);   //  32 admin (change address, role)
+define('BNO_SITEADMIN', 0b01000000);   //  64 siteadmin (change container, siteadmin role)
 
 require_once 'model/User.php';
 require_once 'model/Backend.php';
