@@ -49,17 +49,46 @@ event.preventDefault();
 document.forms.frm_search_ext.submit();
 });
 
-
+/* Gespeicherte Suchen verbergen */
 $('#label_head_close').click(function(event){
-event.preventDefault();
-$(this).parent().parent().hide();
-$('body').removeClass("labelVisible");
+  event.preventDefault();
+  $(this).parent().parent().hide();
+  $('body').removeClass("labelVisible");
+  $.ajax({
+    'url': '',
+    'data':{'CA': 'a_setState', 'storedSearchState': 'hide', }
+  });
+
 });
 
+/* Gespeicherte Suchen anzeige */
+function showStoredSearch() {
+  $('body').addClass("labelVisible");
+  $('#label').show();
+  $.ajax({
+    'url': '',
+    'data':{'CA': 'a_setState', 'storedSearchState': 'show', }
+  });
+}
 $('.search_load a').click(function(event){
-event.preventDefault();
-$('body').addClass("labelVisible");
-$('#label').show();
+  event.preventDefault();
+  showStoredSearch();
+});
+
+/* Absender/Empfaenger tauschen */
+$('#lSearchSender').dblclick(function(event){
+  event.preventDefault();
+  var absender=$('#absender').val(); 
+  var empfaenger=$('#empfaenger').val(); 
+  $('#absender').val(empfaenger);
+  $('#empfaenger').val(absender);
+});
+$('#lSearchRecipient').dblclick(function(event){
+  event.preventDefault();
+  var absender=$('#absender').val(); 
+  var empfaenger=$('#empfaenger').val(); 
+  $('#absender').val(empfaenger);
+  $('#empfaenger').val(absender);
 });
 
 // Mobile Mail Content Close
@@ -336,7 +365,7 @@ $.dpText = {
 
 // Container Switch
 $('#select_container').change(function(){
-var currentArchive=$('archive').val();
+var currentarchive=$('archive').val();
 $.ajax({
     'url': '',
     'data':{ 'CA': 'a_switchContainer',
