@@ -37,7 +37,7 @@ $App->setSession('lastRequestTime',$lastRequestTime);
 
 // If this function returns a value != "", the browser will call loads
 // the page with the CA given in the return string.
-$sessionTimeout = $App->getConfig('SESSION_TIMEOUT');
+$sessionTimeout = $App->getConfig('SESSION_TIMEOUT','480');
 if (! $sessionTimeout) {
     $sessionTimeout = 15;
 }
@@ -45,7 +45,7 @@ $logoffTime = time() - $sessionTimeout * 60;
 
 if ($lastRequestTime <= $logoffTime) {
     $App->log('Session time out for user '.$USER->id,1);
-    $App->resonse('Session timeout','text-plain');
+    $App->response('Session timeout','text-plain');
 }
 
 exit; //async request ends here
