@@ -55,7 +55,7 @@ else if ($App->getConfig('RESEND_MAILTO') == 'to') {
     $MailObject->resendMailto = rtrim($resendAddr,', ');
 }
 
-if ($USER->role == 'ADMIN') {
+if (@$USER->role == 'ADMIN') {
     $MailObject->bennoId    = $EMail->bennoId;
 }
 
