@@ -31,7 +31,7 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-$RUser = clone($User);
+$RUser = clone($USER);
 $RUser->password = session_name().':'.session_id();
 
 // exit
