@@ -54,7 +54,7 @@ if (!$USER->hasArchive($archive)) {
 
 // bild path for REST request
 $rest_path = ltrim($_SERVER['PATH_INFO'],'/');
-$url = $base_url.'/'.$rest_path.'/';
+$url = $base_url.'/'.$rest_path;
 
 $query_data = $_REQUEST;
 
