@@ -32,7 +32,7 @@
  */
 
 $App->setSession('QueryResult',$QueryResult);
-$App->setSession('SearchQuery',$SearchQuery);
+$App->setSession('SearchQuery',$SearchQuery ?? '');
 $App->setSession('Backend',$Backend);
 $App->setSession('EMail',$EMail);
 
@@ -49,7 +49,7 @@ $App->assign('QueryList',$QueryList);
 $App->assign('Backend',$Backend);
 
 $App->assign('SearchQuery',$QueryResult->getQuery());
-$App->assign('queryData',$queryData);
+$App->assign('queryData',$queryData ?? '');
 
 $App->assign('QueryResult',$QueryResult);
 if ($QueryResult) {
